package com.ruoyi.project.business.mapper.contract;

import java.util.List;
import com.ruoyi.project.business.domain.TqContractLiftHistory;
import org.apache.ibatis.annotations.Param;

/**
 * 合同电梯履历Mapper接口
 * 
 * @author ruoyi
 * @date 2024-08-16
 */
public interface TqContractLiftHistoryMapper 
{
    /**
     * 查询合同电梯履历
     * 
     * @param id 合同电梯履历主键
     * @return 合同电梯履历
     */
    public TqContractLiftHistory selectTqContractLiftHistoryById(Long id);

    /**
     * 查询合同电梯履历列表
     * 
     * @param tqContractLiftHistory 合同电梯履历
     * @return 合同电梯履历集合
     */
    public List<TqContractLiftHistory> selectTqContractLiftHistoryList(TqContractLiftHistory tqContractLiftHistory);

    /**
     * 新增合同电梯履历
     * 
     * @param tqContractLiftHistory 合同电梯履历
     * @return 结果
     */
    public int insertTqContractLiftHistory(TqContractLiftHistory tqContractLiftHistory);

    /**
     * 修改合同电梯履历
     * 
     * @param tqContractLiftHistory 合同电梯履历
     * @return 结果
     */
    public int updateTqContractLiftHistory(TqContractLiftHistory tqContractLiftHistory);

    /**
     * 删除合同电梯履历
     * 
     * @param id 合同电梯履历主键
     * @return 结果
     */
    public int deleteTqContractLiftHistoryById(Long id);

    /**
     * 批量删除合同电梯履历
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteTqContractLiftHistoryByIds(Long[] ids);

    /**
     * @Author Chenj
     * @Description 批量导入电梯履历信息
     * @Date 10:26 2024/8/16
     **/
    public int insertTqContractLiftHistoryBatch(List<TqContractLiftHistory> tqContractLiftHistoryList);

    public Long selectVersionMaxFromHistory(@Param("contractNo") String contractNo);
}
